#delim ;
version 15.1;
*
 Bland-Altman plots and parameters
 for the exam candidates dataset.
 SSC packages required:
 somersd, expgen, scsomersd, rcentile, parmest, xsvmat, eclplot
*;

clear all;
set scheme rbn4mono;


*
 Input data
*;
use candidate1, clear;
desc, fu;


*
 Data plots
*;
* Scatter plot *;
scatter atotmark btotmark || line btotmark btotmark, sort || ,
  ylab(10(5)50, labsize(2)) xlab(10(5)50, labsize(2))
  xtitle(, size(2.5))
  legend(row(1) size(1.8125)) xsize(4.6) ysize(4.6);
graph export figseq1.pdf, replace;
more;
* Bland-Altman plot *;
scatter dtotmark mtotmark, yline(0)
  ylab(-8(1)8, labsize(2)) xlab(10(5)50, labsize(2))
  ytitle(, size(2.5)) xtitle(, size(2.5))
  ysize(4.6) xsize(4.6);
graph export figseq2.pdf, replace;
more;


*
 Tau(A,B)
*;
somersd atotmark btotmark, taua transf(z) tdist;
preserve;
parmest, fast escal(N) rename(es_1 N) format(estimate stderr min* max* %8.3f p %-8.2g)
  idstr("Tau(A,B)");
keep if _n>1;
foreach Y of var estimate min* max* {;
  replace `Y'=tanh(`Y');
};
list, abbr(32);
tempfile pf1;
save `"`pf1'"', replace;
restore;


*
 Mean sign
*;
scsomersd dtotmark 0, transf(z) tdist;
preserve;
parmest, fast escal(N_clust) rename(es_1 N) format(estimate min* max* %8.3f p %-8.2g)
  idstr("Mean sign(A-B)");
foreach Y of var estimate min* max* {;
  replace `Y'=tanh(`Y');
};
list, abbr(32);
tempfile pf2;
save `"`pf2'"', replace;
restore;


*
 Tau(A+B,A-B)
*;
somersd mtotmark dtotmark, taua transf(z) tdist;
preserve;
parmest, fast escal(N) rename(es_1 N) format(estimate stderr min* max* %8.3f p %-8.2g)
  idstr("Tau(A+B,A-B)");
keep if _n>1;
foreach Y of var estimate min* max* {;
  replace `Y'=tanh(`Y');
};
list, abbr(32);
tempfile pf3;
save `"`pf3'"', replace;
restore;


*
 Rank statistics for discordance, bias and scale differential
*;
preserve;
clear;
append using `"`pf1'"' `"`pf2'"' `"`pf3'"';
sencode idstr, gene(parmtype);
drop idstr;
lab var parmtype "Parameter type";
eclplot estimate min* max* parmtype, hori rplottype(rspike)
    ylab(1(1)3, labsize(3))
    xlab(0(`=1/12')1, labsize(3) format(%8.4g)) xline(0)
    ytitle(, size(2.5)) xtitle("Parameter value (95% CI)")
    plotregion(margin(t=5 b=5))
    ysize(4.6) xsize(4.6);
graph export figseq3.pdf, replace;
restore;
more;


*
 Percentile differences
*;
rcentile dtotmark, ce(0(12.5)100) transf(z) tdist;
preserve;
xsvmat, from(r(cimat)) name(col) fast;
keyby Percent;
desc, fu;
list, abbr(32);
* Plot *;
local figseq=`figseq'+1;
levelsof Percent, lo(ylabs);
regaxis Centile Minimum Maximum, inc(0) cy(1) ltick(xlabs);
eclplot Centile Minimum Maximum Percent, hori rplottype(rspike)
  ylab(`ylabs', labsize(3))
  xlab(`xlabs', labsize(3)) xline(0)
  ytitle("Percent", size(2.5)) xtitle("Percentile (95% CI) for: Mentor-mentee difference", size(2.5))
  ysize(4.6) xsize(4.6);
graph export figseq4.pdf, replace;
restore;
more;


exit;
