#delim ;
version 15.1;
*
 Ridit spline of mentor marks with respect to mentee marks
 for the exam candidates dataset.
 SSC packages required:
 wridit, bspline, polyspline, parmest eclplot
*;

clear all;
set scheme rbn4mono;

*
 Input data
*;
use candidate1, clear;
desc, fu;

*
 Create ridit of mentee mark
*;
wridit btotmark, gene(btotmark_r) percent;
lab var btotmark_r "Ridit of mentee mark (percent)";
desc btotmark_r, fu;
summ btotmark_r, de;

*
 Create ridit spline basis
*;
polyspline btotmark_r, power(3) refpts(0(12.5)100) gene(rs_) labprefix("btotmark_r@");
desc rs_*;
summ rs_*, de;

*
 Regress mentor mark with respect to mentee ridit spline
*;
regress atotmark rs_*, noconst vce(robust);

*
 Create predicted mentor marks with confidence intervals
*;
predict estimate, xb;
predict stderr, stdp;
gene dof=e(df_r);
lab var estimate "Predicted mentor total mark";
lab var stderr "SE of predicted mentor total mark";
lab var dof "DF of predicted mentor total mark";
parmcip;
desc, fu;

*
 Plot mentee mark and predicted mentor mark against ridit of mentee mark
*;
eclplot estimate min* max* btotmark_r, eplottype(line) rplottype(rline)
  estopts(sort) ciopts(sort)
  baddplot(line btotmark btotmark_r, sort lpattern(shortdash))
  xlab(0(12.5)100, labsize(2.5))
  xtitle(, size(2.5))
  ylab(0(5)50, labsize(2.5))
  ytitle("Observed mentee mark and predicted mentor mark (with 95% CI)", size(2.5))
  legend(on order(1 2) row(1) size(2))
  ysize(4.6) xsize(4.6);
graph export figseq5.pdf, replace;
more;

exit;
